@@ -41,10 +41,8 @@ class ExporterResource(ContextViewBaseResource):
         # Handle an explicit export type to a file
         resp = HttpResponse()
 
-        view_node = view.parse()
-
         exporter_class = exporters[export_type]
-        exporter = exporter_class(view_node.columns)
+        exporter = exporter_class(view)
 
         queryset = view.apply(context.apply(), include_pk=False)
         iterator = queryset.raw()
@@ -56,7 +54,7 @@ class ExporterResource(ContextViewBaseResource):
 
         exporter.write(iterator, resp)
 
-        resp['Content-Disposition'] = 'attachment; filename={0}'.format(filename)
+        resp['Content-Disposition'] = 'attachment; filename="{0}"'.format(filename)
         resp['Content-Type'] = content_type
 
         return resp
